Skip to contents

Evaluated performance parameters across multiple line and cultivar iterations under a randomized complete block layout.

Usage

data(gv_data)

Format

A data.frame containing phenotypic records with wheat morphological traits:

Genotype

Factor or character vector identifying evaluated breeding germplasm lines or cultivars.

Replication

Factor or integer vector indicating experimental replications or blocks within the layout.

PH

Plant Height measured in centimeters (cm).

PL

Peduncle Length measured in centimeters (cm).

SL

Spike Length measured in centimeters (cm).

NOT

Number of tillers per plant.

NOSS

Number of spikelets per spike.

TGW

Thousand grain weight measured in grams (g).

GYPM

Grain yield per meter measured in grams (g).

Experimental plant breeding field trial records.

Examples

data(gv_data, package = "AgriDataTools")
head(gv_data)
#> # A tibble: 6 × 9
#>   Genotype Replication    PH    SL    PL   NOT  NOSS   TGW  GYPM
#>   <chr>          <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl>
#> 1 G1                 1  94    10    25       5  19.2  34.4    98
#> 2 G1                 2  91    10.5  26       6  22    37.6   106
#> 3 G1                 3  93    11    25.4     5  21    35.7    96
#> 4 G2                 1  99.5  10    24       9  18.5  35.1   100
#> 5 G2                 2  94    10.5  24.5    10  17    33.5   103
#> 6 G2                 3  99    10    32       9  19.8  32.2   108